==> kaia_brainbox-0.0.8-py3-none-any.whl: brainbox/framework/controllers/app/logging.py <==
import copy

from ...deployment import LocalExecutor, IExecutor, Command, IFileSystem, Machine
from ...common import Logger
from dataclasses import dataclass
from datetime import datetime



class Log:
    @dataclass
    class Item:
        timestamp: datetime
        comment: str
        command: Command|None
        result: str|None

    def __init__(self):
        self.items: list['Log.Item'] = []


class LogLogger(Logger):
    def __init__(self, log: Log):
        self._log = log

    def report_progress(self, progress: float):
        self.log(f"Progress report: {100*progress}%")

    def log(self, s):
        self._log.items.append(Log.Item(
            datetime.now(),
            s,
            None,
            None
        ))





class LoggingLocalExecutor(IExecutor):
    def __init__(self, log: Log):
        self.base_executor = LocalExecutor()
        self.log = log

    def execute_command(self, command: Command):
        log_item = Log.Item(
            datetime.now(),
            None,
            command,
            None
        )
        command = copy.deepcopy(command)
        if command.options is None:
            command.options = Command.Options()
        command.options.return_output = True
        result = self.base_executor.execute_command(command)
        log_item.result = result
        self.log.items.append(log_item)
        return result

    def get_fs(self) -> IFileSystem:
        return self.base_executor.get_fs()

    def get_machine(self) -> Machine:
        return self.base_executor.get_machine()

==> kaia_brainbox-0.0.9-py3-none-any.whl: brainbox/framework/controllers/app/logging.py <==
import copy

from ...deployment import LocalExecutor, IExecutor, Command, IFileSystem, Machine
from ...common import Logger
from dataclasses import dataclass
from datetime import datetime
from enum import Enum



class Log:
    @dataclass
    class Item:
        timestamp: datetime
        data: str

    def __init__(self):
        self.items: list['Log.Item'] = []


class LogLogger(Logger):
    def __init__(self, log: Log):
        self._log = log

    def report_progress(self, progress: float):
        self.log(f"Progress report: {100*progress}%")

    def log(self, s):
        self._log.items.append(Log.Item(
            datetime.now(),
            s,
        ))





class LoggingLocalExecutor(IExecutor):
    def __init__(self, log: Log):
        self.base_executor = LocalExecutor()
        self.log = log

    def add_item(self, s):
        print(s)
        self.log.items.append(Log.Item(datetime.now(), '< ' + str(s)))

    def execute_command(self, command: Command):
        self.log.items.append(Log.Item(
            datetime.now(),
            '> ' + ' '.join(command.command)
        ))
        command = copy.deepcopy(command)
        if command.options is None:
            command.options = Command.Options()
        command.options.monitor_output = self.add_item

        result = self.base_executor.execute_command(command)
        return result

    def get_fs(self) -> IFileSystem:
        return self.base_executor.get_fs()

    def get_machine(self) -> Machine:
        return self.base_executor.get_machine()
